import { RealTimedEvent } from './providers/jasd/tests/fixtures.ts'
import { fetchEvent } from './fetch_event.ts'
import { returnsNext, stub } from '@std/testing/mock'
import { describe, it } from '@std/testing/bdd'
import { assertEquals, assertRejects } from '@std/assert'
import NotFound = Deno.errors.NotFound

describe('fetchEvent', () => {
  it('throws when no event can be fetched', () => {
    const fakeFetch = stub(
      globalThis,
      'fetch',
      returnsNext([Promise.resolve(new Response(null, { status: 404, statusText: 'Not Found' }))]),
    )

    assertRejects(() => fetchEvent({ id: 'iDoesNotExist' }), NotFound)

    fakeFetch.restore()
  })

  it('works for a jasd api response', async () => {
    const fakeFetch = stub(
      globalThis,
      'fetch',
      returnsNext([Promise.resolve(new Response(JSON.stringify(RealTimedEvent.activity)))]),
    )

    const expectedEvent = {
      data: {
        id: '4610',
        endDate: '2025-03-26T00:00:00+01:00',
        eventDetails: {
          description:
            '<p>Jeden Dienstag (bis auf eine Sommer- und Winterpause) zeigt der Verein Allerweltskino e.V. im Kölner Filmtheater Off Broadway einen Nachhaltigkeitsfilm. Das Programm ist im Internet abrufbar (siehe Kasten rechts).</p>',
          externalLink: 'https://www.allerweltskino.de',
          meetingLink: 'https://www.allerweltskino.de',
        },
        imageUrl: 'https://gemeinschaftswerk-nachhaltigkeit.de/app/api/v1/files/activities/act5.jpg',
        isRemote: false,
        location: {
          city: 'Köln',
          street: 'Bahnhofstr.',
          streetNo: '41',
          zipCode: '50674',
        },
        organisationName: 'Allerweltskino e.V.',
        startDate: '2025-03-26T00:00:00+01:00',
        title: 'RealTimedEvent',
      },
    }

    const result = await fetchEvent({ id: '4160' })

    assertEquals(result, expectedEvent)

    fakeFetch.restore()
  })
})
